@@ -22,8 +22,19 @@ origin <- structure(0, class = c("POSIXt", "POSIXct"))
 #' @param x a character string representing the needed units
 #' @param \dots arguments to or from other methods
 POSIXt.units <- function(x=NULL, ...) {
-	availables.units <- c('second', 'minute', 'hour', 'day', 'week', 'month', 'year')
+	availables.units <- c('second', 'minute', 'hour', 'day', 'week', 'month', 'year', 'AD')
 	if (is.null (x))
-		return (factor (availables.units[c(1:4, 6:7)], availables.units, ordered = TRUE) ) else
+		return (factor (availables.units, availables.units, ordered = TRUE) ) else
+		# return (factor (availables.units[c(1:4, 6:7)], availables.units, ordered = TRUE) ) else
 	return (factor (x, availables.units, ordered=TRUE) )
 }
+
+#' define generic function to compare anything to a numeric
+#'
+#' @name ops.numeric
+#' @aliases Ops,ANY,numeric-method
+#' @aliases Ops,numeric,ANY-method
+setMethod ('Ops', c('numeric', 'ANY'),
+	function (e1, e2) do.call(.Generic, list(e1=e1, e2=as.numeric(e2))))
+setMethod ('Ops', c('ANY', 'numeric'),
+	function (e1, e2) do.call(.Generic, list(e1=as.numeric(e1), e2=e2)))
